ConfigBuilder

Struct ConfigBuilder 

pub struct ConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with internal_build().

Implementations

Source

impl<S: State> ConfigBuilder<S>

pub(crate) fn internal_build(self) -> Config
where S: IsComplete,

Finish building and return the requested object

pub fn name(self, s: impl Into<String>) -> ConfigBuilder<SetName<S>>
where S::Name: IsUnset,

Required.

Network name.

pub fn noise_protocols( self, it: impl IntoIterator<Item = (Version, Protocol)>, ) -> ConfigBuilder<SetNoiseProtocols<S>>

Required.

The supported noise protocols.

Nodes negotiate a common supported version which implies the exact noise protocol parameters they are going to use for the subsequent handshake.

With this map, a node specifies the noise protocol names it supports per version number.

pub fn keypair(self, value: Keypair) -> ConfigBuilder<SetKeypair<S>>
where S::Keypair: IsUnset,

Required.

DH keypair

pub fn bind(self, value: NetAddr) -> ConfigBuilder<SetBind<S>>
where S::Bind: IsUnset,

Required.

Address to bind to.

pub fn parties( self, iter: impl IntoIterator<Item = (PublicKey, NetAddr)>, ) -> ConfigBuilder<SetParties<S>>
where S::Parties: IsUnset,

Required.

Network members with public key and network address.

pub fn peer_budget(self, value: NonZeroUsize) -> ConfigBuilder<SetPeerBudget<S>>
where S::PeerBudget: IsUnset,

Optional (Some / Option setters). Default: NonZeroUsize::new(100).expect("100 > 0").

pub fn maybe_peer_budget( self, value: Option<NonZeroUsize>, ) -> ConfigBuilder<SetPeerBudget<S>>
where S::PeerBudget: IsUnset,

Optional (Some / Option setters). Default: NonZeroUsize::new(100).expect("100 > 0").

pub fn max_message_size( self, value: NonZeroUsize, ) -> ConfigBuilder<SetMaxMessageSize<S>>

Optional (Some / Option setters). Default: NonZeroUsize::new(10485760).expect("10485760 > 0").

Max. number of bytes per message to send or receive.

pub fn maybe_max_message_size( self, value: Option<NonZeroUsize>, ) -> ConfigBuilder<SetMaxMessageSize<S>>

Optional (Some / Option setters). Default: NonZeroUsize::new(10485760).expect("10485760 > 0").

Max. number of bytes per message to send or receive.

pub fn connect_retry_delays( self, it: impl IntoIterator<Item = u8>, ) -> ConfigBuilder<SetConnectRetryDelays<S>>

Optional (Some / Option setters). Default: NonEmpty::new(1, [3, 5, 15, 30]).

Connect retry delays in seconds.

pub fn maybe_connect_retry_delays( self, value: Option<impl IntoIterator<Item = u8>>, ) -> ConfigBuilder<SetConnectRetryDelays<S>>

Optional (Some / Option setters). Default: NonEmpty::new(1, [3, 5, 15, 30]).

Connect retry delays in seconds.

pub fn send_retry_delays( self, it: impl IntoIterator<Item = u8>, ) -> ConfigBuilder<SetSendRetryDelays<S>>

Optional (Some / Option setters). Default: NonEmpty::new(5, [15, 30]).

Send retry delays in seconds.

pub fn maybe_send_retry_delays( self, value: Option<impl IntoIterator<Item = u8>>, ) -> ConfigBuilder<SetSendRetryDelays<S>>

Optional (Some / Option setters). Default: NonEmpty::new(5, [15, 30]).

Send retry delays in seconds.

pub fn random_connect_delay( self, value: bool, ) -> ConfigBuilder<SetRandomConnectDelay<S>>

Optional (Some / Option setters). Default: true.

Randomly delay the initial connect attempt between 0 and 1s.

pub fn maybe_random_connect_delay( self, value: Option<bool>, ) -> ConfigBuilder<SetRandomConnectDelay<S>>

Optional (Some / Option setters). Default: true.

Randomly delay the initial connect attempt between 0 and 1s.

pub fn connect_timeout( self, value: Duration, ) -> ConfigBuilder<SetConnectTimeout<S>>

Optional (Some / Option setters). Default: Duration::from_secs(30).

How long to wait to establish a TCP connection?

pub fn maybe_connect_timeout( self, value: Option<Duration>, ) -> ConfigBuilder<SetConnectTimeout<S>>

Optional (Some / Option setters). Default: Duration::from_secs(30).

How long to wait to establish a TCP connection?

pub fn handshake_timeout( self, value: Duration, ) -> ConfigBuilder<SetHandshakeTimeout<S>>

Optional (Some / Option setters). Default: Duration::from_secs(10).

How long to wait for a noise handshake to complete?

pub fn maybe_handshake_timeout( self, value: Option<Duration>, ) -> ConfigBuilder<SetHandshakeTimeout<S>>

Optional (Some / Option setters). Default: Duration::from_secs(10).

How long to wait for a noise handshake to complete?

pub fn receive_timeout( self, value: Duration, ) -> ConfigBuilder<SetReceiveTimeout<S>>

Optional (Some / Option setters). Default: Duration::from_secs(30).

After sending a message we expect to hear back from the peer.

If we do not receive anything for this duration we reconnect.

pub fn maybe_receive_timeout( self, value: Option<Duration>, ) -> ConfigBuilder<SetReceiveTimeout<S>>

Optional (Some / Option setters). Default: Duration::from_secs(30).

After sending a message we expect to hear back from the peer.

If we do not receive anything for this duration we reconnect.

pub fn backoff_duration( self, value: Duration, ) -> ConfigBuilder<SetBackoffDuration<S>>

Optional (Some / Option setters). Default: Duration::from_secs(30).

If a party is not known we tell it to back off for this amount of time.

This may happen when not all peers have a consistent configuration.

pub fn maybe_backoff_duration( self, value: Option<Duration>, ) -> ConfigBuilder<SetBackoffDuration<S>>

Optional (Some / Option setters). Default: Duration::from_secs(30).

If a party is not known we tell it to back off for this amount of time.

This may happen when not all peers have a consistent configuration.

pub fn metrics(self, value: Arc<dyn Metrics>) -> ConfigBuilder<SetMetrics<S>>
where S::Metrics: IsUnset,

Optional (Some / Option setters). Optional metrics implementation.

pub fn maybe_metrics( self, value: Option<Arc<dyn Metrics>>, ) -> ConfigBuilder<SetMetrics<S>>
where S::Metrics: IsUnset,

Optional (Some / Option setters). Optional metrics implementation.

Source

impl<S: IsComplete> ConfigBuilder<S>

pub fn build(self) -> Config